/**
 * JOnAS: Java(TM) Open Application Server
 * Copyright (C) 2009 Bull S.A.S.
 * Contact: jonas-team@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: InvocationAuditReportVO.as 19356 2010-03-04 21:02:36Z mancelin $
 * --------------------------------------------------------------------------
 */

package org.ow2.jonas.admin.auditconsole.vo {
import com.adobe.cairngorm.vo.IValueObject;

import mx.collections.ArrayCollection;

import org.ow2.jonas.admin.auditconsole.util.IconsUtils;

/**
 * Object that represent an EJB audit report.
 */
[RemoteClass(alias="org.ow2.util.auditreport.impl.InvocationAuditReport")]
[Bindable]
public class InvocationAuditReportVO extends GenericAuditReportVO implements IValueObject {

    public var requestStart:Number = 0;

    public var requestStop:Number = 0;

    public var requestDuration:Number = 0;

    public var businessMethod:String = "";

    public var target:String = "";

    public var methodParameters : Array = null;

    public var methodReturn: Object = null;

    public var paramSize:Number = 0;

    public var returnSize:Number = 0;
    /**
     * Constructor.
     */
    public function InvocationAuditReportVO() {
        super();
    }

    public override function toString():String {
        var ret:String = super.toString() +
        " Target : " + target +
        " Business method : " + businessMethod +
        " Parameters size : " + paramSize + " bytes" +
        " Parameters : " + methodParameters +
        " Return : " + methodReturn +
        " Duration : " + requestDuration + " ms" +
        " Stacktrace : " + methodStackTrace;
        return ret;
    }

    public override function toHTMLString():String {
        var stack:String = "";

        for each (var se:Object in methodStackTrace) {
            stack += se.toString() + "<br/>";
        }
        var ret:String = super.toHTMLString() +
        "<font color=\"#FF0000\"><b>Target</b></font> : " + target + "<br/>" +
        "<font color=\"#FF0000\"><b>Business method</b></font> : " + businessMethod + "<br/>" +
        "<font color=\"#FF0000\"><b>Parameters size</b></font> : " + paramSize + " bytes<br/>" +
        "<font color=\"#FF0000\"><b>Parameters</b></font> : " + methodParameters + "<br/>" +
        "<font color=\"#FF0000\"><b>Return</b></font> : " + methodReturn + "<br/>" +
        "<font color=\"#FF0000\"><b>Duration</b></font> : " + requestDuration + " ms<br/>" +
        "<font color=\"#FF0000\"><b>Stacktrace</b></font> : " + stack + "<br/>";
        return ret;
    }

    public override function isEJBInvocation():Boolean {
        return true;
    }

    public override function isWEBInvocation():Boolean {
        return false;
    }

    public override function isJNDIInvocation():Boolean {
        return false;
    }

    public override function get icon():String {
        return "/../assets/methode.png";
    }

    public override function get iconClass():Class {
        return IconsUtils.getInstance().methodIcon;
    }

    public override function get type():String {
        return "EJB";
    }

    public override function get duration():Number {
        return requestDuration;
    }
    
    public override function get gridTarget():String {
        return target;
    }
}
}